summaryrefslogtreecommitdiffstats
path: root/kdeui/krootpixmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/krootpixmap.h')
-rw-r--r--kdeui/krootpixmap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdeui/krootpixmap.h b/kdeui/krootpixmap.h
index 60f9ac549..d714c93ef 100644
--- a/kdeui/krootpixmap.h
+++ b/kdeui/krootpixmap.h
@@ -43,7 +43,7 @@ class KRootPixmapData;
* @author Geert Jansen <jansen@kde.org>
* @version $Id$
*/
-class KDEUI_EXPORT KRootPixmap: public TQObject
+class KDEUI_EXPORT KRootPixmap: public QObject
{
Q_OBJECT
@@ -137,16 +137,16 @@ public slots:
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically.
*
* @param force Force a tqrepaint, even if the contents did not change.
*/
- void tqrepaint( bool force );
+ void repaint( bool force );
/**
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically. This is equivalent to calling
- * tqrepaint( false ).
+ * repaint( false ).
*/
- void tqrepaint();
+ void repaint();
/**
* Enables custom handling of the background painting. If custom
@@ -137,16 +137,16 @@ public slots:
* as it is handled automatically.
*
- * @param force Force a tqrepaint, even if the contents did not change.
+ * @param force Force a repaint, even if the contents did not change.
*/